@@ -18,7 +18,7 @@
 */
 
 /*
- * $Id: ccid.h 6845 2014-02-14 09:16:01Z rousseau $
+ * $Id: ccid.h 6922 2014-06-16 13:55:33Z rousseau $
  */
 
 typedef struct
@@ -285,56 +285,56 @@ _ccid_descriptor *get_ccid_descriptor(unsigned int reader_index);
 /* Structure returned by Gemalto readers for the CCID Escape command 0x6A */
 struct GEMALTO_FIRMWARE_FEATURES
 {
-	UCHAR	bLogicalLCDLineNumber;	/* Logical number of LCD lines */
-	UCHAR	bLogicalLCDRowNumber;	/* Logical number of characters per LCD line */
-	UCHAR	bLcdInfo;				/* b0 indicates if scrolling is available */
-	UCHAR	bEntryValidationCondition;	/* See PIN_PROPERTIES */
+	unsigned char	bLogicalLCDLineNumber;	/* Logical number of LCD lines */
+	unsigned char	bLogicalLCDRowNumber;	/* Logical number of characters per LCD line */
+	unsigned char	bLcdInfo;				/* b0 indicates if scrolling is available */
+	unsigned char	bEntryValidationCondition;	/* See PIN_PROPERTIES */
 
 	/* Here come the PC/SC bit features to report */
-	UCHAR	VerifyPinStart:1;
-	UCHAR	VerifyPinFinish:1;
-	UCHAR	ModifyPinStart:1;
-	UCHAR	ModifyPinFinish:1;
-	UCHAR	GetKeyPressed:1;
-	UCHAR	VerifyPinDirect:1;
-	UCHAR	ModifyPinDirect:1;
-	UCHAR	Abort:1;
+	unsigned char	VerifyPinStart:1;
+	unsigned char	VerifyPinFinish:1;
+	unsigned char	ModifyPinStart:1;
+	unsigned char	ModifyPinFinish:1;
+	unsigned char	GetKeyPressed:1;
+	unsigned char	VerifyPinDirect:1;
+	unsigned char	ModifyPinDirect:1;
+	unsigned char	Abort:1;
 
-	UCHAR	GetKey:1;
-	UCHAR	WriteDisplay:1;
-	UCHAR	SetSpeMessage:1;
-	UCHAR	RFUb1:5;
+	unsigned char	GetKey:1;
+	unsigned char	WriteDisplay:1;
+	unsigned char	SetSpeMessage:1;
+	unsigned char	RFUb1:5;
 
-	UCHAR	RFUb2[2];
+	unsigned char	RFUb2[2];
 
 	/* Additional flags */
-	UCHAR	bTimeOut2:1;
-	UCHAR	bListSupportedLanguages:1;	/* Reader is able to indicate
+	unsigned char	bTimeOut2:1;
+	unsigned char	bListSupportedLanguages:1;	/* Reader is able to indicate
 	   the list of supported languages through CCID-ESC 0x6B */
-	UCHAR	bNumberMessageFix:1;	/* Reader handles correctly shifts
+	unsigned char	bNumberMessageFix:1;	/* Reader handles correctly shifts
 		made by bNumberMessage in PIN modification data structure */
-	UCHAR	bPPDUSupportOverXferBlock:1;	/* Reader supports PPDU over
+	unsigned char	bPPDUSupportOverXferBlock:1;	/* Reader supports PPDU over
 		PC_to_RDR_XferBlock command */
-	UCHAR	bPPDUSupportOverEscape:1;	/* Reader supports PPDU over
+	unsigned char	bPPDUSupportOverEscape:1;	/* Reader supports PPDU over
 		PC_to_RDR_Escape command with abData[0]=0xFF */
-	UCHAR	RFUb3:3;
+	unsigned char	RFUb3:3;
 
-	UCHAR	RFUb4[3];
+	unsigned char	RFUb4[3];
 
-	UCHAR	VersionNumber;	/* ?? */
-	UCHAR	MinimumPINSize;	/* for Verify and Modify */
-	UCHAR	MaximumPINSize;
+	unsigned char	VersionNumber;	/* ?? */
+	unsigned char	MinimumPINSize;	/* for Verify and Modify */
+	unsigned char	MaximumPINSize;
 
 	/* Miscellaneous reader features */
-	UCHAR	Firewall:1;
-	UCHAR	RFUb5:7;
+	unsigned char	Firewall:1;
+	unsigned char	RFUb5:7;
 
 	/* The following fields, FirewalledCommand_SW1 and
 	 * FirewalledCommand_SW2 are only valid if Firewall=1
 	 * These fields give the SW1 SW2 value used by the reader to
 	 * indicate a command has been firewalled */
-	UCHAR	FirewalledCommand_SW1;
-	UCHAR	FirewalledCommand_SW2;
-	UCHAR	RFUb6[3];
+	unsigned char	FirewalledCommand_SW1;
+	unsigned char	FirewalledCommand_SW2;
+	unsigned char	RFUb6[3];
 };
 
